import * as api from './api'
import { dict, UserPageQuery, compute, CreateCrudOptionsProps, CreateCrudOptionsRet } from '@fast-crud/fast-crud'
import { inject } from 'vue'
import { SpCampaignPuchasedOtherProductsColumn } from '/@/views/adManage/utils/commonTabColumn.js'

export const createCrudOptions = function ({ crudExpose, context }: CreateCrudOptionsProps): CreateCrudOptionsRet {
	const pageRequest = async (query: UserPageQuery) => {
		query['profileId'] = context.profile.value.profile_id
		query['startDate'] = context.dateRange.value[0]
		query['endDate'] = context.dateRange.value[1]
		return await api.GetList(query)
	}

	//权限判定
	const hasPermissions = inject('$hasPermissions')

	return {
		crudOptions: {
			table: {
				height: 800,
			},
			container: {
				fixedHeight: false,
			},
			actionbar: {
				show: false,
			},
			search: {
				show: false,
			},
			toolbar: {
				buttons: {
					search: {
						show: true,
					},
					compact: {
						show: false,
					},
				},
			},
			request: {
				pageRequest,
			},
			rowHandle: {
				show: false,
			},
			columns: {
				adProduct: {
					title: '推广商品',
					column: {
						width: '250px',
					},
				},
				purchasedProduct: {
					title: '购买的其它商品',
				},
				state: {
					title: '状态',
				},
				campaignName: {
					title: '广告活动',
					column: {
						width: '200px',
					},
					search: {
						show: true,
						component: {
							props: {
								clearable: true,
							},
						},
					},
					form: {
						rules: [{ required: true, message: '必填项' }],
					},
				},
				adGroup: {
					title: '广告组',
				},
				matchType: {
					title: '定向',
				},
				...SpCampaignPuchasedOtherProductsColumn,
			},
		},
	}
}
